dnoticias\_tables.templatetags package
======================================

Submodules
----------

dnoticias\_tables.templatetags.tables module
--------------------------------------------

.. automodule:: dnoticias_tables.templatetags.tables
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: dnoticias_tables.templatetags
   :members:
   :undoc-members:
   :show-inheritance:
